.tippy-box[data-animation=fade][data-state=hidden]{opacity:0}[data-tippy-root]{max-width:calc(100vw - 10px)}.tippy-box{position:relative;background-color:#333;color:#fff;border-radius:4px;font-size:14px;line-height:1.4;white-space:normal;outline:0;transition-property:transform,visibility,opacity}.tippy-box[data-placement^=top]>.tippy-arrow{bottom:0}.tippy-box[data-placement^=top]>.tippy-arrow:before{bottom:-7px;left:0;border-width:8px 8px 0;border-top-color:initial;transform-origin:center top}.tippy-box[data-placement^=bottom]>.tippy-arrow{top:0}.tippy-box[data-placement^=bottom]>.tippy-arrow:before{top:-7px;left:0;border-width:0 8px 8px;border-bottom-color:initial;transform-origin:center bottom}.tippy-box[data-placement^=left]>.tippy-arrow{right:0}.tippy-box[data-placement^=left]>.tippy-arrow:before{border-width:8px 0 8px 8px;border-left-color:initial;right:-7px;transform-origin:center left}.tippy-box[data-placement^=right]>.tippy-arrow{left:0}.tippy-box[data-placement^=right]>.tippy-arrow:before{left:-7px;border-width:8px 8px 8px 0;border-right-color:initial;transform-origin:center right}.tippy-box[data-inertia][data-state=visible]{transition-timing-function:cubic-bezier(.54,1.5,.38,1.11)}.tippy-arrow{width:16px;height:16px;color:#333}.tippy-arrow:before{content:"";position:absolute;border-color:transparent;border-style:solid}.tippy-content{position:relative;padding:5px 9px;z-index:1}
/*
! tailwindcss v3.4.1 | MIT License | https://tailwindcss.com
*//*
1. Prevent padding and border from affecting element width. (https://github.com/mozdevs/cssremedy/issues/4)
2. Allow adding a border to an element by just adding a border-width. (https://github.com/tailwindcss/tailwindcss/pull/116)
*/

*,
::before,
::after {
  box-sizing: border-box; /* 1 */
  border-width: 0; /* 2 */
  border-style: solid; /* 2 */
  border-color: #e5e7eb; /* 2 */
}

::before,
::after {
  --tw-content: '';
}

/*
1. Use a consistent sensible line-height in all browsers.
2. Prevent adjustments of font size after orientation changes in iOS.
3. Use a more readable tab size.
4. Use the user's configured `sans` font-family by default.
5. Use the user's configured `sans` font-feature-settings by default.
6. Use the user's configured `sans` font-variation-settings by default.
7. Disable tap highlights on iOS
*/

html,
:host {
  line-height: 1.5; /* 1 */
  -webkit-text-size-adjust: 100%; /* 2 */
  -moz-tab-size: 4; /* 3 */
  -o-tab-size: 4;
     tab-size: 4; /* 3 */
  font-family: ui-sans-serif, system-ui, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji"; /* 4 */
  font-feature-settings: normal; /* 5 */
  font-variation-settings: normal; /* 6 */
  -webkit-tap-highlight-color: transparent; /* 7 */
}

/*
1. Remove the margin in all browsers.
2. Inherit line-height from `html` so users can set them as a class directly on the `html` element.
*/

body {
  margin: 0; /* 1 */
  line-height: inherit; /* 2 */
}

/*
1. Add the correct height in Firefox.
2. Correct the inheritance of border color in Firefox. (https://bugzilla.mozilla.org/show_bug.cgi?id=190655)
3. Ensure horizontal rules are visible by default.
*/

hr {
  height: 0; /* 1 */
  color: inherit; /* 2 */
  border-top-width: 1px; /* 3 */
}

/*
Add the correct text decoration in Chrome, Edge, and Safari.
*/

abbr:where([title]) {
  -webkit-text-decoration: underline dotted;
          text-decoration: underline dotted;
}

/*
Remove the default font size and weight for headings.
*/

h1,
h2,
h3,
h4,
h5,
h6 {
  font-size: inherit;
  font-weight: inherit;
}

/*
Reset links to optimize for opt-in styling instead of opt-out.
*/

a {
  color: inherit;
  text-decoration: inherit;
}

/*
Add the correct font weight in Edge and Safari.
*/

b,
strong {
  font-weight: bolder;
}

/*
1. Use the user's configured `mono` font-family by default.
2. Use the user's configured `mono` font-feature-settings by default.
3. Use the user's configured `mono` font-variation-settings by default.
4. Correct the odd `em` font sizing in all browsers.
*/

code,
kbd,
samp,
pre {
  font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace; /* 1 */
  font-feature-settings: normal; /* 2 */
  font-variation-settings: normal; /* 3 */
  font-size: 1em; /* 4 */
}

/*
Add the correct font size in all browsers.
*/

small {
  font-size: 80%;
}

/*
Prevent `sub` and `sup` elements from affecting the line height in all browsers.
*/

sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sub {
  bottom: -0.25em;
}

sup {
  top: -0.5em;
}

/*
1. Remove text indentation from table contents in Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=999088, https://bugs.webkit.org/show_bug.cgi?id=201297)
2. Correct table border color inheritance in all Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=935729, https://bugs.webkit.org/show_bug.cgi?id=195016)
3. Remove gaps between table borders by default.
*/

table {
  text-indent: 0; /* 1 */
  border-color: inherit; /* 2 */
  border-collapse: collapse; /* 3 */
}

/*
1. Change the font styles in all browsers.
2. Remove the margin in Firefox and Safari.
3. Remove default padding in all browsers.
*/

button,
input,
optgroup,
select,
textarea {
  font-family: inherit; /* 1 */
  font-feature-settings: inherit; /* 1 */
  font-variation-settings: inherit; /* 1 */
  font-size: 100%; /* 1 */
  font-weight: inherit; /* 1 */
  line-height: inherit; /* 1 */
  color: inherit; /* 1 */
  margin: 0; /* 2 */
  padding: 0; /* 3 */
}

/*
Remove the inheritance of text transform in Edge and Firefox.
*/

button,
select {
  text-transform: none;
}

/*
1. Correct the inability to style clickable types in iOS and Safari.
2. Remove default button styles.
*/

button,
[type='button'],
[type='reset'],
[type='submit'] {
  -webkit-appearance: button; /* 1 */
  background-color: transparent; /* 2 */
  background-image: none; /* 2 */
}

/*
Use the modern Firefox focus style for all focusable elements.
*/

:-moz-focusring {
  outline: auto;
}

/*
Remove the additional `:invalid` styles in Firefox. (https://github.com/mozilla/gecko-dev/blob/2f9eacd9d3d995c937b4251a5557d95d494c9be1/layout/style/res/forms.css#L728-L737)
*/

:-moz-ui-invalid {
  box-shadow: none;
}

/*
Add the correct vertical alignment in Chrome and Firefox.
*/

progress {
  vertical-align: baseline;
}

/*
Correct the cursor style of increment and decrement buttons in Safari.
*/

::-webkit-inner-spin-button,
::-webkit-outer-spin-button {
  height: auto;
}

/*
1. Correct the odd appearance in Chrome and Safari.
2. Correct the outline style in Safari.
*/

[type='search'] {
  -webkit-appearance: textfield; /* 1 */
  outline-offset: -2px; /* 2 */
}

/*
Remove the inner padding in Chrome and Safari on macOS.
*/

::-webkit-search-decoration {
  -webkit-appearance: none;
}

/*
1. Correct the inability to style clickable types in iOS and Safari.
2. Change font properties to `inherit` in Safari.
*/

::-webkit-file-upload-button {
  -webkit-appearance: button; /* 1 */
  font: inherit; /* 2 */
}

/*
Add the correct display in Chrome and Safari.
*/

summary {
  display: list-item;
}

/*
Removes the default spacing and border for appropriate elements.
*/

blockquote,
dl,
dd,
h1,
h2,
h3,
h4,
h5,
h6,
hr,
figure,
p,
pre {
  margin: 0;
}

fieldset {
  margin: 0;
  padding: 0;
}

legend {
  padding: 0;
}

ol,
ul,
menu {
  list-style: none;
  margin: 0;
  padding: 0;
}

/*
Reset default styling for dialogs.
*/
dialog {
  padding: 0;
}

/*
Prevent resizing textareas horizontally by default.
*/

textarea {
  resize: vertical;
}

/*
1. Reset the default placeholder opacity in Firefox. (https://github.com/tailwindlabs/tailwindcss/issues/3300)
2. Set the default placeholder color to the user's configured gray 400 color.
*/

input::-moz-placeholder, textarea::-moz-placeholder {
  opacity: 1; /* 1 */
  color: #9ca3af; /* 2 */
}

input::placeholder,
textarea::placeholder {
  opacity: 1; /* 1 */
  color: #9ca3af; /* 2 */
}

/*
Set the default cursor for buttons.
*/

button,
[role="button"] {
  cursor: pointer;
}

/*
Make sure disabled buttons don't get the pointer cursor.
*/
:disabled {
  cursor: default;
}

/*
1. Make replaced elements `display: block` by default. (https://github.com/mozdevs/cssremedy/issues/14)
2. Add `vertical-align: middle` to align replaced elements more sensibly by default. (https://github.com/jensimmons/cssremedy/issues/14#issuecomment-634934210)
   This can trigger a poorly considered lint error in some tools but is included by design.
*/

img,
svg,
video,
canvas,
audio,
iframe,
embed,
object {
  display: block; /* 1 */
  vertical-align: middle; /* 2 */
}

/*
Constrain images and videos to the parent width and preserve their intrinsic aspect ratio. (https://github.com/mozdevs/cssremedy/issues/14)
*/

img,
video {
  max-width: 100%;
  height: auto;
}

/* Make elements with the HTML hidden attribute stay hidden by default */
[hidden] {
  display: none;
}

*, ::before, ::after {
  --tw-border-spacing-x: 0;
  --tw-border-spacing-y: 0;
  --tw-translate-x: 0;
  --tw-translate-y: 0;
  --tw-rotate: 0;
  --tw-skew-x: 0;
  --tw-skew-y: 0;
  --tw-scale-x: 1;
  --tw-scale-y: 1;
  --tw-pan-x:  ;
  --tw-pan-y:  ;
  --tw-pinch-zoom:  ;
  --tw-scroll-snap-strictness: proximity;
  --tw-gradient-from-position:  ;
  --tw-gradient-via-position:  ;
  --tw-gradient-to-position:  ;
  --tw-ordinal:  ;
  --tw-slashed-zero:  ;
  --tw-numeric-figure:  ;
  --tw-numeric-spacing:  ;
  --tw-numeric-fraction:  ;
  --tw-ring-inset:  ;
  --tw-ring-offset-width: 0px;
  --tw-ring-offset-color: #fff;
  --tw-ring-color: rgb(59 130 246 / 0.5);
  --tw-ring-offset-shadow: 0 0 #0000;
  --tw-ring-shadow: 0 0 #0000;
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  --tw-blur:  ;
  --tw-brightness:  ;
  --tw-contrast:  ;
  --tw-grayscale:  ;
  --tw-hue-rotate:  ;
  --tw-invert:  ;
  --tw-saturate:  ;
  --tw-sepia:  ;
  --tw-drop-shadow:  ;
  --tw-backdrop-blur:  ;
  --tw-backdrop-brightness:  ;
  --tw-backdrop-contrast:  ;
  --tw-backdrop-grayscale:  ;
  --tw-backdrop-hue-rotate:  ;
  --tw-backdrop-invert:  ;
  --tw-backdrop-opacity:  ;
  --tw-backdrop-saturate:  ;
  --tw-backdrop-sepia:  ;
}

::backdrop {
  --tw-border-spacing-x: 0;
  --tw-border-spacing-y: 0;
  --tw-translate-x: 0;
  --tw-translate-y: 0;
  --tw-rotate: 0;
  --tw-skew-x: 0;
  --tw-skew-y: 0;
  --tw-scale-x: 1;
  --tw-scale-y: 1;
  --tw-pan-x:  ;
  --tw-pan-y:  ;
  --tw-pinch-zoom:  ;
  --tw-scroll-snap-strictness: proximity;
  --tw-gradient-from-position:  ;
  --tw-gradient-via-position:  ;
  --tw-gradient-to-position:  ;
  --tw-ordinal:  ;
  --tw-slashed-zero:  ;
  --tw-numeric-figure:  ;
  --tw-numeric-spacing:  ;
  --tw-numeric-fraction:  ;
  --tw-ring-inset:  ;
  --tw-ring-offset-width: 0px;
  --tw-ring-offset-color: #fff;
  --tw-ring-color: rgb(59 130 246 / 0.5);
  --tw-ring-offset-shadow: 0 0 #0000;
  --tw-ring-shadow: 0 0 #0000;
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  --tw-blur:  ;
  --tw-brightness:  ;
  --tw-contrast:  ;
  --tw-grayscale:  ;
  --tw-hue-rotate:  ;
  --tw-invert:  ;
  --tw-saturate:  ;
  --tw-sepia:  ;
  --tw-drop-shadow:  ;
  --tw-backdrop-blur:  ;
  --tw-backdrop-brightness:  ;
  --tw-backdrop-contrast:  ;
  --tw-backdrop-grayscale:  ;
  --tw-backdrop-hue-rotate:  ;
  --tw-backdrop-invert:  ;
  --tw-backdrop-opacity:  ;
  --tw-backdrop-saturate:  ;
  --tw-backdrop-sepia:  ;
}
.container {
  width: 100%;
}
@media (min-width: 640px) {

  .container {
    max-width: 640px;
  }
}
@media (min-width: 768px) {

  .container {
    max-width: 768px;
  }
}
@media (min-width: 1024px) {

  .container {
    max-width: 1024px;
  }
}
@media (min-width: 1280px) {

  .container {
    max-width: 1280px;
  }
}
@media (min-width: 1536px) {

  .container {
    max-width: 1536px;
  }
}
.pointer-events-none {
  pointer-events: none;
}
.visible {
  visibility: visible;
}
.invisible {
  visibility: hidden;
}
.collapse {
  visibility: collapse;
}
.static {
  position: static;
}
.fixed {
  position: fixed;
}
.absolute {
  position: absolute;
}
.relative {
  position: relative;
}
.sticky {
  position: sticky;
}
.inset-0 {
  inset: 0px;
}
.bottom-0 {
  bottom: 0px;
}
.bottom-2 {
  bottom: 0.5rem;
}
.bottom-3 {
  bottom: 0.75rem;
}
.left-0 {
  left: 0px;
}
.left-1\/2 {
  left: 50%;
}
.left-3 {
  left: 0.75rem;
}
.right-0 {
  right: 0px;
}
.right-4 {
  right: 1rem;
}
.top-0 {
  top: 0px;
}
.top-1 {
  top: 0.25rem;
}
.top-1\/2 {
  top: 50%;
}
.top-10 {
  top: 2.5rem;
}
.top-2 {
  top: 0.5rem;
}
.isolate {
  isolation: isolate;
}
.z-10 {
  z-index: 10;
}
.z-40 {
  z-index: 40;
}
.col-span-2 {
  grid-column: span 2 / span 2;
}
.m-1 {
  margin: 0.25rem;
}
.m-2 {
  margin: 0.5rem;
}
.-mx-\[--gutter\] {
  margin-left: calc(var(--gutter) * -1);
  margin-right: calc(var(--gutter) * -1);
}
.my-1 {
  margin-top: 0.25rem;
  margin-bottom: 0.25rem;
}
.-ml-1 {
  margin-left: -0.25rem;
}
.mb-2 {
  margin-bottom: 0.5rem;
}
.mb-3 {
  margin-bottom: 0.75rem;
}
.mb-4 {
  margin-bottom: 1rem;
}
.ml-0 {
  margin-left: 0px;
}
.ml-0\.5 {
  margin-left: 0.125rem;
}
.ml-1 {
  margin-left: 0.25rem;
}
.ml-2 {
  margin-left: 0.5rem;
}
.mr-1 {
  margin-right: 0.25rem;
}
.mr-1\.5 {
  margin-right: 0.375rem;
}
.mr-2 {
  margin-right: 0.5rem;
}
.mr-3 {
  margin-right: 0.75rem;
}
.mr-4 {
  margin-right: 1rem;
}
.mr-5 {
  margin-right: 1.25rem;
}
.mt-1 {
  margin-top: 0.25rem;
}
.mt-2 {
  margin-top: 0.5rem;
}
.block {
  display: block;
}
.inline-block {
  display: inline-block;
}
.inline {
  display: inline;
}
.flex {
  display: flex;
}
.inline-flex {
  display: inline-flex;
}
.table {
  display: table;
}
.flow-root {
  display: flow-root;
}
.grid {
  display: grid;
}
.hidden {
  display: none;
}
.size-\[1\.125rem\] {
  width: 1.125rem;
  height: 1.125rem;
}
.size-\[max\(100\%\2c 2\.75rem\)\] {
  width: max(100%,2.75rem);
  height: max(100%,2.75rem);
}
.h-10 {
  height: 2.5rem;
}
.h-12 {
  height: 3rem;
}
.h-16 {
  height: 4rem;
}
.h-20 {
  height: 5rem;
}
.h-3 {
  height: 0.75rem;
}
.h-4 {
  height: 1rem;
}
.h-5 {
  height: 1.25rem;
}
.h-6 {
  height: 1.5rem;
}
.h-\[50dvh\] {
  height: 50dvh;
}
.h-full {
  height: 100%;
}
.min-h-0 {
  min-height: 0px;
}
.min-h-12 {
  min-height: 3rem;
}
.min-h-8 {
  min-height: 2rem;
}
.w-10 {
  width: 2.5rem;
}
.w-20 {
  width: 5rem;
}
.w-3 {
  width: 0.75rem;
}
.w-3\/5 {
  width: 60%;
}
.w-4 {
  width: 1rem;
}
.w-5 {
  width: 1.25rem;
}
.w-6 {
  width: 1.5rem;
}
.w-\[70dvw\] {
  width: 70dvw;
}
.w-full {
  width: 100%;
}
.w-min {
  width: -moz-min-content;
  width: min-content;
}
.min-w-0 {
  min-width: 0px;
}
.min-w-full {
  min-width: 100%;
}
.max-w-40 {
  max-width: 10rem;
}
.max-w-64 {
  max-width: 16rem;
}
.max-w-80 {
  max-width: 20rem;
}
.max-w-full {
  max-width: 100%;
}
.flex-1 {
  flex: 1 1 0%;
}
.shrink-0 {
  flex-shrink: 0;
}
.flex-grow {
  flex-grow: 1;
}
.border-collapse {
  border-collapse: collapse;
}
.border-separate {
  border-collapse: separate;
}
.-translate-x-1\/2 {
  --tw-translate-x: -50%;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}
.-translate-y-1\/2 {
  --tw-translate-y: -50%;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}
.translate-x-0 {
  --tw-translate-x: 0px;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}
.transform {
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}
@keyframes spin {

  to {
    transform: rotate(360deg);
  }
}
.animate-spin {
  animation: spin 1s linear infinite;
}
.cursor-default {
  cursor: default;
}
.cursor-pointer {
  cursor: pointer;
}
.select-none {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.select-all {
  -webkit-user-select: all;
     -moz-user-select: all;
          user-select: all;
}
.resize {
  resize: both;
}
.appearance-none {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
}
.grid-cols-\[1fr\2c min-content\] {
  grid-template-columns: 1fr min-content;
}
.grid-cols-\[1fr_auto\] {
  grid-template-columns: 1fr auto;
}
.grid-cols-\[min-content_1fr\] {
  grid-template-columns: min-content 1fr;
}
.grid-cols-\[min-content_auto\] {
  grid-template-columns: min-content auto;
}
.grid-rows-\[min-content_1fr\] {
  grid-template-rows: min-content 1fr;
}
.flex-row {
  flex-direction: row;
}
.flex-col {
  flex-direction: column;
}
.flex-col-reverse {
  flex-direction: column-reverse;
}
.items-end {
  align-items: flex-end;
}
.items-center {
  align-items: center;
}
.items-baseline {
  align-items: baseline;
}
.items-stretch {
  align-items: stretch;
}
.justify-start {
  justify-content: flex-start;
}
.justify-end {
  justify-content: flex-end;
}
.justify-center {
  justify-content: center;
}
.justify-between {
  justify-content: space-between;
}
.gap-x-2 {
  -moz-column-gap: 0.5rem;
       column-gap: 0.5rem;
}
.gap-x-4 {
  -moz-column-gap: 1rem;
       column-gap: 1rem;
}
.gap-x-8 {
  -moz-column-gap: 2rem;
       column-gap: 2rem;
}
.gap-y-1 {
  row-gap: 0.25rem;
}
.gap-y-2 {
  row-gap: 0.5rem;
}
.space-y-2 > :not([hidden]) ~ :not([hidden]) {
  --tw-space-y-reverse: 0;
  margin-top: calc(0.5rem * calc(1 - var(--tw-space-y-reverse)));
  margin-bottom: calc(0.5rem * var(--tw-space-y-reverse));
}
.space-y-3 > :not([hidden]) ~ :not([hidden]) {
  --tw-space-y-reverse: 0;
  margin-top: calc(0.75rem * calc(1 - var(--tw-space-y-reverse)));
  margin-bottom: calc(0.75rem * var(--tw-space-y-reverse));
}
.space-y-8 > :not([hidden]) ~ :not([hidden]) {
  --tw-space-y-reverse: 0;
  margin-top: calc(2rem * calc(1 - var(--tw-space-y-reverse)));
  margin-bottom: calc(2rem * var(--tw-space-y-reverse));
}
.place-self-end {
  place-self: end;
}
.self-center {
  align-self: center;
}
.self-stretch {
  align-self: stretch;
}
.overflow-auto {
  overflow: auto;
}
.overflow-hidden {
  overflow: hidden;
}
.overflow-clip {
  overflow: clip;
}
.overflow-x-auto {
  overflow-x: auto;
}
.overflow-y-auto {
  overflow-y: auto;
}
.overflow-x-hidden {
  overflow-x: hidden;
}
.overflow-y-hidden {
  overflow-y: hidden;
}
.truncate {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.text-ellipsis {
  text-overflow: ellipsis;
}
.whitespace-nowrap {
  white-space: nowrap;
}
.whitespace-pre-wrap {
  white-space: pre-wrap;
}
.text-balance {
  text-wrap: balance;
}
.break-all {
  word-break: break-all;
}
.rounded {
  border-radius: 0.25rem;
}
.rounded-2xl {
  border-radius: 1rem;
}
.rounded-full {
  border-radius: 9999px;
}
.rounded-lg {
  border-radius: 0.5rem;
}
.rounded-md {
  border-radius: 0.375rem;
}
.rounded-l-full {
  border-top-left-radius: 9999px;
  border-bottom-left-radius: 9999px;
}
.rounded-r-full {
  border-top-right-radius: 9999px;
  border-bottom-right-radius: 9999px;
}
.border {
  border-width: 1px;
}
.border-0 {
  border-width: 0px;
}
.border-b {
  border-bottom-width: 1px;
}
.border-b-2 {
  border-bottom-width: 2px;
}
.border-b-\[3px\] {
  border-bottom-width: 3px;
}
.border-l {
  border-left-width: 1px;
}
.border-l-0 {
  border-left-width: 0px;
}
.border-l-4 {
  border-left-width: 4px;
}
.border-r {
  border-right-width: 1px;
}
.border-r-0 {
  border-right-width: 0px;
}
.border-t {
  border-top-width: 1px;
}
.border-black\/10 {
  border-color: rgb(0 0 0 / 0.1);
}
.border-black\/15 {
  border-color: rgb(0 0 0 / 0.15);
}
.border-black\/5 {
  border-color: rgb(0 0 0 / 0.05);
}
.border-blue-500 {
  --tw-border-opacity: 1;
  border-color: rgb(59 130 246 / var(--tw-border-opacity));
}
.border-gray-100 {
  --tw-border-opacity: 1;
  border-color: rgb(243 244 246 / var(--tw-border-opacity));
}
.border-gray-200 {
  --tw-border-opacity: 1;
  border-color: rgb(229 231 235 / var(--tw-border-opacity));
}
.border-gray-300 {
  --tw-border-opacity: 1;
  border-color: rgb(209 213 219 / var(--tw-border-opacity));
}
.border-transparent {
  border-color: transparent;
}
.border-zinc-950\/10 {
  border-color: rgb(9 9 11 / 0.1);
}
.border-zinc-950\/5 {
  border-color: rgb(9 9 11 / 0.05);
}
.border-b-gray-200 {
  --tw-border-opacity: 1;
  border-bottom-color: rgb(229 231 235 / var(--tw-border-opacity));
}
.border-b-gray-900 {
  --tw-border-opacity: 1;
  border-bottom-color: rgb(17 24 39 / var(--tw-border-opacity));
}
.border-b-zinc-950\/10 {
  border-bottom-color: rgb(9 9 11 / 0.1);
}
.border-l-gray-200 {
  --tw-border-opacity: 1;
  border-left-color: rgb(229 231 235 / var(--tw-border-opacity));
}
.border-l-lime-300 {
  --tw-border-opacity: 1;
  border-left-color: rgb(190 242 100 / var(--tw-border-opacity));
}
.border-l-orange-200 {
  --tw-border-opacity: 1;
  border-left-color: rgb(254 215 170 / var(--tw-border-opacity));
}
.border-l-transparent {
  border-left-color: transparent;
}
.border-l-zinc-950\/5 {
  border-left-color: rgb(9 9 11 / 0.05);
}
.border-r-blue-500 {
  --tw-border-opacity: 1;
  border-right-color: rgb(59 130 246 / var(--tw-border-opacity));
}
.border-r-gray-200 {
  --tw-border-opacity: 1;
  border-right-color: rgb(229 231 235 / var(--tw-border-opacity));
}
.border-t-gray-200 {
  --tw-border-opacity: 1;
  border-top-color: rgb(229 231 235 / var(--tw-border-opacity));
}
.bg-\[--btn-border\] {
  background-color: var(--btn-border);
}
.bg-black\/10 {
  background-color: rgb(0 0 0 / 0.1);
}
.bg-black\/5 {
  background-color: rgb(0 0 0 / 0.05);
}
.bg-black\/\[\.08\] {
  background-color: rgb(0 0 0 / .08);
}
.bg-blue-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(219 234 254 / var(--tw-bg-opacity));
}
.bg-blue-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(191 219 254 / var(--tw-bg-opacity));
}
.bg-blue-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(147 197 253 / var(--tw-bg-opacity));
}
.bg-blue-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(37 99 235 / var(--tw-bg-opacity));
}
.bg-gray-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(243 244 246 / var(--tw-bg-opacity));
}
.bg-gray-100\/90 {
  background-color: rgb(243 244 246 / 0.9);
}
.bg-gray-100\/95 {
  background-color: rgb(243 244 246 / 0.95);
}
.bg-gray-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(229 231 235 / var(--tw-bg-opacity));
}
.bg-gray-200\/90 {
  background-color: rgb(229 231 235 / 0.9);
}
.bg-gray-900 {
  --tw-bg-opacity: 1;
  background-color: rgb(17 24 39 / var(--tw-bg-opacity));
}
.bg-green-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(187 247 208 / var(--tw-bg-opacity));
}
.bg-green-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(134 239 172 / var(--tw-bg-opacity));
}
.bg-lime-50\/30 {
  background-color: rgb(247 254 231 / 0.3);
}
.bg-lime-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(101 163 13 / var(--tw-bg-opacity));
}
.bg-orange-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 215 170 / var(--tw-bg-opacity));
}
.bg-orange-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(253 186 116 / var(--tw-bg-opacity));
}
.bg-orange-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(251 146 60 / var(--tw-bg-opacity));
}
.bg-orange-50\/30 {
  background-color: rgb(255 247 237 / 0.3);
}
.bg-orange-500\/40 {
  background-color: rgb(249 115 22 / 0.4);
}
.bg-pink-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(251 207 232 / var(--tw-bg-opacity));
}
.bg-purple-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(233 213 255 / var(--tw-bg-opacity));
}
.bg-red-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 226 226 / var(--tw-bg-opacity));
}
.bg-red-100\/90 {
  background-color: rgb(254 226 226 / 0.9);
}
.bg-red-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(252 165 165 / var(--tw-bg-opacity));
}
.bg-red-400 {
  --tw-bg-opacity: 1;
  background-color: rgb(248 113 113 / var(--tw-bg-opacity));
}
.bg-red-600 {
  --tw-bg-opacity: 1;
  background-color: rgb(220 38 38 / var(--tw-bg-opacity));
}
.bg-transparent {
  background-color: transparent;
}
.bg-white {
  --tw-bg-opacity: 1;
  background-color: rgb(255 255 255 / var(--tw-bg-opacity));
}
.bg-white\/40 {
  background-color: rgb(255 255 255 / 0.4);
}
.bg-white\/50 {
  background-color: rgb(255 255 255 / 0.5);
}
.bg-white\/70 {
  background-color: rgb(255 255 255 / 0.7);
}
.bg-white\/90 {
  background-color: rgb(255 255 255 / 0.9);
}
.bg-yellow-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(254 240 138 / var(--tw-bg-opacity));
}
.bg-yellow-300 {
  --tw-bg-opacity: 1;
  background-color: rgb(253 224 71 / var(--tw-bg-opacity));
}
.bg-zinc-200 {
  --tw-bg-opacity: 1;
  background-color: rgb(228 228 231 / var(--tw-bg-opacity));
}
.fill-black {
  fill: #000;
}
.fill-green-600 {
  fill: #16a34a;
}
.fill-white {
  fill: #fff;
}
.p-0 {
  padding: 0px;
}
.p-0\.5 {
  padding: 0.125rem;
}
.p-1 {
  padding: 0.25rem;
}
.p-2 {
  padding: 0.5rem;
}
.p-3 {
  padding: 0.75rem;
}
.p-4 {
  padding: 1rem;
}
.p-\[3px\] {
  padding: 3px;
}
.px-1 {
  padding-left: 0.25rem;
  padding-right: 0.25rem;
}
.px-1\.5 {
  padding-left: 0.375rem;
  padding-right: 0.375rem;
}
.px-2 {
  padding-left: 0.5rem;
  padding-right: 0.5rem;
}
.px-2\.5 {
  padding-left: 0.625rem;
  padding-right: 0.625rem;
}
.px-3 {
  padding-left: 0.75rem;
  padding-right: 0.75rem;
}
.px-4 {
  padding-left: 1rem;
  padding-right: 1rem;
}
.px-5 {
  padding-left: 1.25rem;
  padding-right: 1.25rem;
}
.px-\[calc\(theme\(spacing\[3\.5\]\)-1px\)\] {
  padding-left: calc(0.875rem - 1px);
  padding-right: calc(0.875rem - 1px);
}
.py-0 {
  padding-top: 0px;
  padding-bottom: 0px;
}
.py-0\.5 {
  padding-top: 0.125rem;
  padding-bottom: 0.125rem;
}
.py-1 {
  padding-top: 0.25rem;
  padding-bottom: 0.25rem;
}
.py-1\.5 {
  padding-top: 0.375rem;
  padding-bottom: 0.375rem;
}
.py-2 {
  padding-top: 0.5rem;
  padding-bottom: 0.5rem;
}
.py-2\.5 {
  padding-top: 0.625rem;
  padding-bottom: 0.625rem;
}
.py-3 {
  padding-top: 0.75rem;
  padding-bottom: 0.75rem;
}
.py-4 {
  padding-top: 1rem;
  padding-bottom: 1rem;
}
.py-6 {
  padding-top: 1.5rem;
  padding-bottom: 1.5rem;
}
.py-\[2px\] {
  padding-top: 2px;
  padding-bottom: 2px;
}
.py-\[calc\(theme\(spacing\[2\.5\]\)-1px\)\] {
  padding-top: calc(0.625rem - 1px);
  padding-bottom: calc(0.625rem - 1px);
}
.pb-2 {
  padding-bottom: 0.5rem;
}
.pb-3 {
  padding-bottom: 0.75rem;
}
.pb-4 {
  padding-bottom: 1rem;
}
.pl-0 {
  padding-left: 0px;
}
.pl-0\.5 {
  padding-left: 0.125rem;
}
.pl-1 {
  padding-left: 0.25rem;
}
.pl-1\.5 {
  padding-left: 0.375rem;
}
.pl-2 {
  padding-left: 0.5rem;
}
.pl-4 {
  padding-left: 1rem;
}
.pl-5 {
  padding-left: 1.25rem;
}
.pr-0 {
  padding-right: 0px;
}
.pr-0\.5 {
  padding-right: 0.125rem;
}
.pr-1 {
  padding-right: 0.25rem;
}
.pr-2 {
  padding-right: 0.5rem;
}
.pr-3 {
  padding-right: 0.75rem;
}
.pt-1 {
  padding-top: 0.25rem;
}
.pt-3 {
  padding-top: 0.75rem;
}
.pt-7 {
  padding-top: 1.75rem;
}
.text-left {
  text-align: left;
}
.text-center {
  text-align: center;
}
.align-middle {
  vertical-align: middle;
}
.align-text-top {
  vertical-align: text-top;
}
.font-mono {
  font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;
}
.text-2xl {
  font-size: 1.5rem;
  line-height: 2rem;
}
.text-\[13px\] {
  font-size: 13px;
}
.text-base {
  font-size: 1rem;
  line-height: 1.5rem;
}
.text-base\/6 {
  font-size: 1rem;
  line-height: 1.5rem;
}
.text-lg {
  font-size: 1.125rem;
  line-height: 1.75rem;
}
.text-sm {
  font-size: 0.875rem;
  line-height: 1.25rem;
}
.text-sm\/6 {
  font-size: 0.875rem;
  line-height: 1.5rem;
}
.text-xl {
  font-size: 1.25rem;
  line-height: 1.75rem;
}
.text-xs {
  font-size: 0.75rem;
  line-height: 1rem;
}
.text-xs\/6 {
  font-size: 0.75rem;
  line-height: 1.5rem;
}
.font-bold {
  font-weight: 700;
}
.font-medium {
  font-weight: 500;
}
.font-normal {
  font-weight: 400;
}
.font-semibold {
  font-weight: 600;
}
.uppercase {
  text-transform: uppercase;
}
.italic {
  font-style: italic;
}
.text-amber-950 {
  --tw-text-opacity: 1;
  color: rgb(69 26 3 / var(--tw-text-opacity));
}
.text-black {
  --tw-text-opacity: 1;
  color: rgb(0 0 0 / var(--tw-text-opacity));
}
.text-black\/20 {
  color: rgb(0 0 0 / 0.2);
}
.text-blue-300 {
  --tw-text-opacity: 1;
  color: rgb(147 197 253 / var(--tw-text-opacity));
}
.text-blue-700 {
  --tw-text-opacity: 1;
  color: rgb(29 78 216 / var(--tw-text-opacity));
}
.text-cyan-950 {
  --tw-text-opacity: 1;
  color: rgb(8 51 68 / var(--tw-text-opacity));
}
.text-gray-400 {
  --tw-text-opacity: 1;
  color: rgb(156 163 175 / var(--tw-text-opacity));
}
.text-gray-500 {
  --tw-text-opacity: 1;
  color: rgb(107 114 128 / var(--tw-text-opacity));
}
.text-gray-600 {
  --tw-text-opacity: 1;
  color: rgb(75 85 99 / var(--tw-text-opacity));
}
.text-gray-700 {
  --tw-text-opacity: 1;
  color: rgb(55 65 81 / var(--tw-text-opacity));
}
.text-gray-800 {
  --tw-text-opacity: 1;
  color: rgb(31 41 55 / var(--tw-text-opacity));
}
.text-gray-900 {
  --tw-text-opacity: 1;
  color: rgb(17 24 39 / var(--tw-text-opacity));
}
.text-green-600 {
  --tw-text-opacity: 1;
  color: rgb(22 163 74 / var(--tw-text-opacity));
}
.text-green-700 {
  --tw-text-opacity: 1;
  color: rgb(21 128 61 / var(--tw-text-opacity));
}
.text-inherit {
  color: inherit;
}
.text-lime-950 {
  --tw-text-opacity: 1;
  color: rgb(26 46 5 / var(--tw-text-opacity));
}
.text-orange-800 {
  --tw-text-opacity: 1;
  color: rgb(154 52 18 / var(--tw-text-opacity));
}
.text-pink-700 {
  --tw-text-opacity: 1;
  color: rgb(190 24 93 / var(--tw-text-opacity));
}
.text-purple-600 {
  --tw-text-opacity: 1;
  color: rgb(147 51 234 / var(--tw-text-opacity));
}
.text-red-400 {
  --tw-text-opacity: 1;
  color: rgb(248 113 113 / var(--tw-text-opacity));
}
.text-red-600 {
  --tw-text-opacity: 1;
  color: rgb(220 38 38 / var(--tw-text-opacity));
}
.text-red-700 {
  --tw-text-opacity: 1;
  color: rgb(185 28 28 / var(--tw-text-opacity));
}
.text-red-800 {
  --tw-text-opacity: 1;
  color: rgb(153 27 27 / var(--tw-text-opacity));
}
.text-white {
  --tw-text-opacity: 1;
  color: rgb(255 255 255 / var(--tw-text-opacity));
}
.text-yellow-800 {
  --tw-text-opacity: 1;
  color: rgb(133 77 14 / var(--tw-text-opacity));
}
.text-yellow-950 {
  --tw-text-opacity: 1;
  color: rgb(66 32 6 / var(--tw-text-opacity));
}
.text-zinc-500 {
  --tw-text-opacity: 1;
  color: rgb(113 113 122 / var(--tw-text-opacity));
}
.text-zinc-950 {
  --tw-text-opacity: 1;
  color: rgb(9 9 11 / var(--tw-text-opacity));
}
.opacity-0 {
  opacity: 0;
}
.opacity-100 {
  opacity: 1;
}
.opacity-20 {
  opacity: 0.2;
}
.opacity-25 {
  opacity: 0.25;
}
.opacity-5 {
  opacity: 0.05;
}
.opacity-50 {
  opacity: 0.5;
}
.opacity-75 {
  opacity: 0.75;
}
.shadow {
  --tw-shadow: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);
  --tw-shadow-colored: 0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}
.shadow-\[0_0_5px_10px_rgba\(255\2c 255\2c 255\2c \.9\)\] {
  --tw-shadow: 0 0 5px 10px rgba(255,255,255,.9);
  --tw-shadow-colored: 0 0 5px 10px var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}
.shadow-inner {
  --tw-shadow: inset 0 2px 4px 0 rgb(0 0 0 / 0.05);
  --tw-shadow-colored: inset 0 2px 4px 0 var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}
.shadow-lg {
  --tw-shadow: 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);
  --tw-shadow-colored: 0 10px 15px -3px var(--tw-shadow-color), 0 4px 6px -4px var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}
.shadow-sm {
  --tw-shadow: 0 1px 2px 0 rgb(0 0 0 / 0.05);
  --tw-shadow-colored: 0 1px 2px 0 var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}
.outline {
  outline-style: solid;
}
.ring {
  --tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);
  --tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(3px + var(--tw-ring-offset-width)) var(--tw-ring-color);
  box-shadow: var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);
}
.ring-1 {
  --tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);
  --tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);
  box-shadow: var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);
}
.ring-inset {
  --tw-ring-inset: inset;
}
.ring-black\/5 {
  --tw-ring-color: rgb(0 0 0 / 0.05);
}
.filter {
  filter: var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow);
}
.transition {
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}
.transition-all {
  transition-property: all;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}
.transition-colors {
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}
.transition-opacity {
  transition-property: opacity;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}
.duration-0 {
  transition-duration: 0s;
}
.duration-100 {
  transition-duration: 100ms;
}
.duration-200 {
  transition-duration: 200ms;
}
.ease-in-out {
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
}
.\[--btn-bg\:theme\(colors\.amber\.400\)\] {
  --btn-bg: #fbbf24;
}
.\[--btn-bg\:theme\(colors\.blue\.600\)\] {
  --btn-bg: #2563eb;
}
.\[--btn-bg\:theme\(colors\.cyan\.300\)\] {
  --btn-bg: #67e8f9;
}
.\[--btn-bg\:theme\(colors\.emerald\.600\)\] {
  --btn-bg: #059669;
}
.\[--btn-bg\:theme\(colors\.fuchsia\.500\)\] {
  --btn-bg: #d946ef;
}
.\[--btn-bg\:theme\(colors\.green\.600\)\] {
  --btn-bg: #16a34a;
}
.\[--btn-bg\:theme\(colors\.indigo\.500\)\] {
  --btn-bg: #6366f1;
}
.\[--btn-bg\:theme\(colors\.lime\.300\)\] {
  --btn-bg: #bef264;
}
.\[--btn-bg\:theme\(colors\.orange\.500\)\] {
  --btn-bg: #f97316;
}
.\[--btn-bg\:theme\(colors\.pink\.500\)\] {
  --btn-bg: #ec4899;
}
.\[--btn-bg\:theme\(colors\.purple\.500\)\] {
  --btn-bg: #a855f7;
}
.\[--btn-bg\:theme\(colors\.red\.600\)\] {
  --btn-bg: #dc2626;
}
.\[--btn-bg\:theme\(colors\.rose\.500\)\] {
  --btn-bg: #f43f5e;
}
.\[--btn-bg\:theme\(colors\.sky\.500\)\] {
  --btn-bg: #0ea5e9;
}
.\[--btn-bg\:theme\(colors\.teal\.600\)\] {
  --btn-bg: #0d9488;
}
.\[--btn-bg\:theme\(colors\.violet\.500\)\] {
  --btn-bg: #8b5cf6;
}
.\[--btn-bg\:theme\(colors\.yellow\.300\)\] {
  --btn-bg: #fde047;
}
.\[--btn-bg\:theme\(colors\.zinc\.600\)\] {
  --btn-bg: #52525b;
}
.\[--btn-bg\:theme\(colors\.zinc\.900\)\] {
  --btn-bg: #18181b;
}
.\[--btn-bg\:white\] {
  --btn-bg: white;
}
.\[--btn-border\:theme\(colors\.amber\.500\/80\%\)\] {
  --btn-border: rgb(245 158 11 / 80%);
}
.\[--btn-border\:theme\(colors\.blue\.700\/90\%\)\] {
  --btn-border: rgb(29 78 216 / 90%);
}
.\[--btn-border\:theme\(colors\.cyan\.400\/80\%\)\] {
  --btn-border: rgb(34 211 238 / 80%);
}
.\[--btn-border\:theme\(colors\.emerald\.700\/90\%\)\] {
  --btn-border: rgb(4 120 87 / 90%);
}
.\[--btn-border\:theme\(colors\.fuchsia\.600\/90\%\)\] {
  --btn-border: rgb(192 38 211 / 90%);
}
.\[--btn-border\:theme\(colors\.green\.700\/90\%\)\] {
  --btn-border: rgb(21 128 61 / 90%);
}
.\[--btn-border\:theme\(colors\.indigo\.600\/90\%\)\] {
  --btn-border: rgb(79 70 229 / 90%);
}
.\[--btn-border\:theme\(colors\.lime\.400\/80\%\)\] {
  --btn-border: rgb(163 230 53 / 80%);
}
.\[--btn-border\:theme\(colors\.orange\.600\/90\%\)\] {
  --btn-border: rgb(234 88 12 / 90%);
}
.\[--btn-border\:theme\(colors\.pink\.600\/90\%\)\] {
  --btn-border: rgb(219 39 119 / 90%);
}
.\[--btn-border\:theme\(colors\.purple\.600\/90\%\)\] {
  --btn-border: rgb(147 51 234 / 90%);
}
.\[--btn-border\:theme\(colors\.red\.700\/90\%\)\] {
  --btn-border: rgb(185 28 28 / 90%);
}
.\[--btn-border\:theme\(colors\.rose\.600\/90\%\)\] {
  --btn-border: rgb(225 29 72 / 90%);
}
.\[--btn-border\:theme\(colors\.sky\.600\/80\%\)\] {
  --btn-border: rgb(2 132 199 / 80%);
}
.\[--btn-border\:theme\(colors\.teal\.700\/90\%\)\] {
  --btn-border: rgb(15 118 110 / 90%);
}
.\[--btn-border\:theme\(colors\.violet\.600\/90\%\)\] {
  --btn-border: rgb(124 58 237 / 90%);
}
.\[--btn-border\:theme\(colors\.yellow\.400\/80\%\)\] {
  --btn-border: rgb(250 204 21 / 80%);
}
.\[--btn-border\:theme\(colors\.zinc\.700\/90\%\)\] {
  --btn-border: rgb(63 63 70 / 90%);
}
.\[--btn-border\:theme\(colors\.zinc\.950\/10\%\)\] {
  --btn-border: rgb(9 9 11 / 10%);
}
.\[--btn-border\:theme\(colors\.zinc\.950\/90\%\)\] {
  --btn-border: rgb(9 9 11 / 90%);
}
.\[--btn-hover-overlay\:theme\(colors\.white\/10\%\)\] {
  --btn-hover-overlay: rgb(255 255 255 / 10%);
}
.\[--btn-hover-overlay\:theme\(colors\.white\/25\%\)\] {
  --btn-hover-overlay: rgb(255 255 255 / 25%);
}
.\[--btn-hover-overlay\:theme\(colors\.zinc\.950\/2\.5\%\)\] {
  --btn-hover-overlay: rgb(9 9 11 / 2.5%);
}
.\[--btn-icon\:theme\(colors\.amber\.600\)\] {
  --btn-icon: #d97706;
}
.\[--btn-icon\:theme\(colors\.blue\.400\)\] {
  --btn-icon: #60a5fa;
}
.\[--btn-icon\:theme\(colors\.cyan\.500\)\] {
  --btn-icon: #06b6d4;
}
.\[--btn-icon\:theme\(colors\.fuchsia\.300\)\] {
  --btn-icon: #f0abfc;
}
.\[--btn-icon\:theme\(colors\.indigo\.300\)\] {
  --btn-icon: #a5b4fc;
}
.\[--btn-icon\:theme\(colors\.lime\.600\)\] {
  --btn-icon: #65a30d;
}
.\[--btn-icon\:theme\(colors\.orange\.300\)\] {
  --btn-icon: #fdba74;
}
.\[--btn-icon\:theme\(colors\.pink\.300\)\] {
  --btn-icon: #f9a8d4;
}
.\[--btn-icon\:theme\(colors\.purple\.300\)\] {
  --btn-icon: #d8b4fe;
}
.\[--btn-icon\:theme\(colors\.red\.300\)\] {
  --btn-icon: #fca5a5;
}
.\[--btn-icon\:theme\(colors\.rose\.300\)\] {
  --btn-icon: #fda4af;
}
.\[--btn-icon\:theme\(colors\.violet\.300\)\] {
  --btn-icon: #c4b5fd;
}
.\[--btn-icon\:theme\(colors\.white\/60\%\)\] {
  --btn-icon: rgb(255 255 255 / 60%);
}
.\[--btn-icon\:theme\(colors\.yellow\.600\)\] {
  --btn-icon: #ca8a04;
}
.\[--btn-icon\:theme\(colors\.zinc\.400\)\] {
  --btn-icon: #a1a1aa;
}
.\[--btn-icon\:theme\(colors\.zinc\.500\)\] {
  --btn-icon: #71717a;
}
.\[--switch-bg-ring\:theme\(colors\.amber\.500\/80\%\)\] {
  --switch-bg-ring: rgb(245 158 11 / 80%);
}
.\[--switch-bg-ring\:theme\(colors\.black\/15\%\)\] {
  --switch-bg-ring: rgb(0 0 0 / 15%);
}
.\[--switch-bg-ring\:theme\(colors\.blue\.700\/90\%\)\] {
  --switch-bg-ring: rgb(29 78 216 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.cyan\.400\/80\%\)\] {
  --switch-bg-ring: rgb(34 211 238 / 80%);
}
.\[--switch-bg-ring\:theme\(colors\.emerald\.600\/90\%\)\] {
  --switch-bg-ring: rgb(5 150 105 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.fuchsia\.600\/90\%\)\] {
  --switch-bg-ring: rgb(192 38 211 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.green\.700\/90\%\)\] {
  --switch-bg-ring: rgb(21 128 61 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.indigo\.600\/90\%\)\] {
  --switch-bg-ring: rgb(79 70 229 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.lime\.400\/80\%\)\] {
  --switch-bg-ring: rgb(163 230 53 / 80%);
}
.\[--switch-bg-ring\:theme\(colors\.orange\.600\/90\%\)\] {
  --switch-bg-ring: rgb(234 88 12 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.pink\.600\/90\%\)\] {
  --switch-bg-ring: rgb(219 39 119 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.purple\.600\/90\%\)\] {
  --switch-bg-ring: rgb(147 51 234 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.red\.700\/90\%\)\] {
  --switch-bg-ring: rgb(185 28 28 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.rose\.600\/90\%\)\] {
  --switch-bg-ring: rgb(225 29 72 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.sky\.600\/80\%\)\] {
  --switch-bg-ring: rgb(2 132 199 / 80%);
}
.\[--switch-bg-ring\:theme\(colors\.teal\.700\/90\%\)\] {
  --switch-bg-ring: rgb(15 118 110 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.violet\.600\/90\%\)\] {
  --switch-bg-ring: rgb(124 58 237 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.yellow\.400\/80\%\)\] {
  --switch-bg-ring: rgb(250 204 21 / 80%);
}
.\[--switch-bg-ring\:theme\(colors\.zinc\.700\/90\%\)\] {
  --switch-bg-ring: rgb(63 63 70 / 90%);
}
.\[--switch-bg-ring\:theme\(colors\.zinc\.950\/90\%\)\] {
  --switch-bg-ring: rgb(9 9 11 / 90%);
}
.\[--switch-bg\:theme\(colors\.amber\.400\)\] {
  --switch-bg: #fbbf24;
}
.\[--switch-bg\:theme\(colors\.blue\.600\)\] {
  --switch-bg: #2563eb;
}
.\[--switch-bg\:theme\(colors\.cyan\.300\)\] {
  --switch-bg: #67e8f9;
}
.\[--switch-bg\:theme\(colors\.emerald\.500\)\] {
  --switch-bg: #10b981;
}
.\[--switch-bg\:theme\(colors\.fuchsia\.500\)\] {
  --switch-bg: #d946ef;
}
.\[--switch-bg\:theme\(colors\.green\.600\)\] {
  --switch-bg: #16a34a;
}
.\[--switch-bg\:theme\(colors\.indigo\.500\)\] {
  --switch-bg: #6366f1;
}
.\[--switch-bg\:theme\(colors\.lime\.300\)\] {
  --switch-bg: #bef264;
}
.\[--switch-bg\:theme\(colors\.orange\.500\)\] {
  --switch-bg: #f97316;
}
.\[--switch-bg\:theme\(colors\.pink\.500\)\] {
  --switch-bg: #ec4899;
}
.\[--switch-bg\:theme\(colors\.purple\.500\)\] {
  --switch-bg: #a855f7;
}
.\[--switch-bg\:theme\(colors\.red\.600\)\] {
  --switch-bg: #dc2626;
}
.\[--switch-bg\:theme\(colors\.rose\.500\)\] {
  --switch-bg: #f43f5e;
}
.\[--switch-bg\:theme\(colors\.sky\.500\)\] {
  --switch-bg: #0ea5e9;
}
.\[--switch-bg\:theme\(colors\.teal\.600\)\] {
  --switch-bg: #0d9488;
}
.\[--switch-bg\:theme\(colors\.violet\.500\)\] {
  --switch-bg: #8b5cf6;
}
.\[--switch-bg\:theme\(colors\.yellow\.300\)\] {
  --switch-bg: #fde047;
}
.\[--switch-bg\:theme\(colors\.zinc\.600\)\] {
  --switch-bg: #52525b;
}
.\[--switch-bg\:theme\(colors\.zinc\.900\)\] {
  --switch-bg: #18181b;
}
.\[--switch-bg\:white\] {
  --switch-bg: white;
}
.\[--switch-ring\:theme\(colors\.blue\.700\/90\%\)\] {
  --switch-ring: rgb(29 78 216 / 90%);
}
.\[--switch-ring\:theme\(colors\.emerald\.600\/90\%\)\] {
  --switch-ring: rgb(5 150 105 / 90%);
}
.\[--switch-ring\:theme\(colors\.fuchsia\.600\/90\%\)\] {
  --switch-ring: rgb(192 38 211 / 90%);
}
.\[--switch-ring\:theme\(colors\.green\.700\/90\%\)\] {
  --switch-ring: rgb(21 128 61 / 90%);
}
.\[--switch-ring\:theme\(colors\.indigo\.600\/90\%\)\] {
  --switch-ring: rgb(79 70 229 / 90%);
}
.\[--switch-ring\:theme\(colors\.orange\.600\/90\%\)\] {
  --switch-ring: rgb(234 88 12 / 90%);
}
.\[--switch-ring\:theme\(colors\.pink\.600\/90\%\)\] {
  --switch-ring: rgb(219 39 119 / 90%);
}
.\[--switch-ring\:theme\(colors\.purple\.600\/90\%\)\] {
  --switch-ring: rgb(147 51 234 / 90%);
}
.\[--switch-ring\:theme\(colors\.red\.700\/90\%\)\] {
  --switch-ring: rgb(185 28 28 / 90%);
}
.\[--switch-ring\:theme\(colors\.rose\.600\/90\%\)\] {
  --switch-ring: rgb(225 29 72 / 90%);
}
.\[--switch-ring\:theme\(colors\.sky\.600\/80\%\)\] {
  --switch-ring: rgb(2 132 199 / 80%);
}
.\[--switch-ring\:theme\(colors\.teal\.700\/90\%\)\] {
  --switch-ring: rgb(15 118 110 / 90%);
}
.\[--switch-ring\:theme\(colors\.violet\.600\/90\%\)\] {
  --switch-ring: rgb(124 58 237 / 90%);
}
.\[--switch-ring\:theme\(colors\.zinc\.700\/90\%\)\] {
  --switch-ring: rgb(63 63 70 / 90%);
}
.\[--switch-ring\:theme\(colors\.zinc\.950\/90\%\)\] {
  --switch-ring: rgb(9 9 11 / 90%);
}
.\[--switch-ring\:transparent\] {
  --switch-ring: transparent;
}
.\[--switch-shadow\:theme\(colors\.black\/10\%\)\] {
  --switch-shadow: rgb(0 0 0 / 10%);
}
.\[--switch-shadow\:theme\(colors\.blue\.900\/20\%\)\] {
  --switch-shadow: rgb(30 58 138 / 20%);
}
.\[--switch-shadow\:theme\(colors\.emerald\.900\/20\%\)\] {
  --switch-shadow: rgb(6 78 59 / 20%);
}
.\[--switch-shadow\:theme\(colors\.fuchsia\.900\/20\%\)\] {
  --switch-shadow: rgb(112 26 117 / 20%);
}
.\[--switch-shadow\:theme\(colors\.green\.900\/20\%\)\] {
  --switch-shadow: rgb(20 83 45 / 20%);
}
.\[--switch-shadow\:theme\(colors\.indigo\.900\/20\%\)\] {
  --switch-shadow: rgb(49 46 129 / 20%);
}
.\[--switch-shadow\:theme\(colors\.orange\.900\/20\%\)\] {
  --switch-shadow: rgb(124 45 18 / 20%);
}
.\[--switch-shadow\:theme\(colors\.pink\.900\/20\%\)\] {
  --switch-shadow: rgb(131 24 67 / 20%);
}
.\[--switch-shadow\:theme\(colors\.purple\.900\/20\%\)\] {
  --switch-shadow: rgb(88 28 135 / 20%);
}
.\[--switch-shadow\:theme\(colors\.red\.900\/20\%\)\] {
  --switch-shadow: rgb(127 29 29 / 20%);
}
.\[--switch-shadow\:theme\(colors\.rose\.900\/20\%\)\] {
  --switch-shadow: rgb(136 19 55 / 20%);
}
.\[--switch-shadow\:theme\(colors\.sky\.900\/20\%\)\] {
  --switch-shadow: rgb(12 74 110 / 20%);
}
.\[--switch-shadow\:theme\(colors\.teal\.900\/20\%\)\] {
  --switch-shadow: rgb(19 78 74 / 20%);
}
.\[--switch-shadow\:theme\(colors\.violet\.900\/20\%\)\] {
  --switch-shadow: rgb(76 29 149 / 20%);
}
.\[--switch-shadow\:transparent\] {
  --switch-shadow: transparent;
}
.\[--switch\:theme\(colors\.amber\.950\)\] {
  --switch: #451a03;
}
.\[--switch\:theme\(colors\.cyan\.950\)\] {
  --switch: #083344;
}
.\[--switch\:theme\(colors\.lime\.950\)\] {
  --switch: #1a2e05;
}
.\[--switch\:theme\(colors\.yellow\.950\)\] {
  --switch: #422006;
}
.\[--switch\:theme\(colors\.zinc\.950\)\] {
  --switch: #09090b;
}
.\[--switch\:white\] {
  --switch: white;
}

html,
body,
#root {
  height: 100%;
}

.placeholder\:text-zinc-500::-moz-placeholder {
  --tw-text-opacity: 1;
  color: rgb(113 113 122 / var(--tw-text-opacity));
}

.placeholder\:text-zinc-500::placeholder {
  --tw-text-opacity: 1;
  color: rgb(113 113 122 / var(--tw-text-opacity));
}

.before\:absolute::before {
  content: var(--tw-content);
  position: absolute;
}

.before\:inset-0::before {
  content: var(--tw-content);
  inset: 0px;
}

.before\:inset-px::before {
  content: var(--tw-content);
  inset: 1px;
}

.before\:-z-10::before {
  content: var(--tw-content);
  z-index: -10;
}

.before\:rounded-\[calc\(theme\(borderRadius\.lg\)-1px\)\]::before {
  content: var(--tw-content);
  border-radius: calc(0.5rem - 1px);
}

.before\:bg-\[--btn-bg\]::before {
  content: var(--tw-content);
  background-color: var(--btn-bg);
}

.before\:bg-white::before {
  content: var(--tw-content);
  --tw-bg-opacity: 1;
  background-color: rgb(255 255 255 / var(--tw-bg-opacity));
}

.before\:shadow::before {
  content: var(--tw-content);
  --tw-shadow: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);
  --tw-shadow-colored: 0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.after\:pointer-events-none::after {
  content: var(--tw-content);
  pointer-events: none;
}

.after\:absolute::after {
  content: var(--tw-content);
  position: absolute;
}

.after\:inset-0::after {
  content: var(--tw-content);
  inset: 0px;
}

.after\:-z-10::after {
  content: var(--tw-content);
  z-index: -10;
}

.after\:rounded-\[calc\(theme\(borderRadius\.lg\)-1px\)\]::after {
  content: var(--tw-content);
  border-radius: calc(0.5rem - 1px);
}

.after\:rounded-lg::after {
  content: var(--tw-content);
  border-radius: 0.5rem;
}

.after\:shadow-\[shadow\:inset_0_1px_theme\(colors\.white\/15\%\)\]::after {
  content: var(--tw-content);
  --tw-shadow: inset 0 1px rgb(255 255 255 / 15%);
  --tw-shadow-colored: inset 0 1px var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.after\:ring-inset::after {
  content: var(--tw-content);
  --tw-ring-inset: inset;
}

.after\:ring-transparent::after {
  content: var(--tw-content);
  --tw-ring-color: transparent;
}

.first\:border-l-0:first-child {
  border-left-width: 0px;
}

.first\:pl-\[var\(--gutter\2c theme\(spacing\.2\)\)\]:first-child {
  padding-left: var(--gutter,0.5rem);
}

.first\:pt-5:first-child {
  padding-top: 1.25rem;
}

.last\:border-r-0:last-child {
  border-right-width: 0px;
}

.last\:pr-\[var\(--gutter\2c theme\(spacing\.2\)\)\]:last-child {
  padding-right: var(--gutter,0.5rem);
}

.even\:bg-zinc-950\/\[2\.5\%\]:nth-child(even) {
  background-color: rgb(9 9 11 / 2.5%);
}

.hover\:border-gray-400:hover {
  --tw-border-opacity: 1;
  border-color: rgb(156 163 175 / var(--tw-border-opacity));
}

.hover\:bg-gray-100:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(243 244 246 / var(--tw-bg-opacity));
}

.hover\:bg-gray-200\/90:hover {
  background-color: rgb(229 231 235 / 0.9);
}

.hover\:bg-gray-50:hover {
  --tw-bg-opacity: 1;
  background-color: rgb(249 250 251 / var(--tw-bg-opacity));
}

.hover\:bg-zinc-950\/5:hover {
  background-color: rgb(9 9 11 / 0.05);
}

.hover\:bg-zinc-950\/\[2\.5\%\]:hover {
  background-color: rgb(9 9 11 / 2.5%);
}

.hover\:text-blue-700:hover {
  --tw-text-opacity: 1;
  color: rgb(29 78 216 / var(--tw-text-opacity));
}

.hover\:text-gray-700:hover {
  --tw-text-opacity: 1;
  color: rgb(55 65 81 / var(--tw-text-opacity));
}

.hover\:text-gray-900:hover {
  --tw-text-opacity: 1;
  color: rgb(17 24 39 / var(--tw-text-opacity));
}

.focus\:outline-none:focus {
  outline: 2px solid transparent;
  outline-offset: 2px;
}

.active\:shadow-inner:active {
  --tw-shadow: inset 0 2px 4px 0 rgb(0 0 0 / 0.05);
  --tw-shadow-colored: inset 0 2px 4px 0 var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.group:hover .group-hover\:border-gray-400 {
  --tw-border-opacity: 1;
  border-color: rgb(156 163 175 / var(--tw-border-opacity));
}

.group:hover .group-hover\:bg-gray-100 {
  --tw-bg-opacity: 1;
  background-color: rgb(243 244 246 / var(--tw-bg-opacity));
}

.has-\[\[data-slot\=description\]\]\:space-y-6:has([data-slot=description]) > :not([hidden]) ~ :not([hidden]) {
  --tw-space-y-reverse: 0;
  margin-top: calc(1.5rem * calc(1 - var(--tw-space-y-reverse)));
  margin-bottom: calc(1.5rem * var(--tw-space-y-reverse));
}

.has-\[\[data-disabled\]\]\:opacity-50:has([data-disabled]) {
  opacity: 0.5;
}

.has-\[\[data-row-link\]\[data-focus\]\]\:outline:has([data-row-link][data-focus]) {
  outline-style: solid;
}

.has-\[\[data-row-link\]\[data-focus\]\]\:outline-2:has([data-row-link][data-focus]) {
  outline-width: 2px;
}

.has-\[\[data-row-link\]\[data-focus\]\]\:-outline-offset-2:has([data-row-link][data-focus]) {
  outline-offset: -2px;
}

.has-\[\[data-row-link\]\[data-focus\]\]\:outline-blue-500:has([data-row-link][data-focus]) {
  outline-color: #3b82f6;
}

.before\:has-\[\[data-disabled\]\]\:bg-zinc-950\/5:has([data-disabled])::before {
  content: var(--tw-content);
  background-color: rgb(9 9 11 / 0.05);
}

.before\:has-\[\[data-disabled\]\]\:shadow-none:has([data-disabled])::before {
  content: var(--tw-content);
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.before\:has-\[\[data-invalid\]\]\:shadow-red-500\/10:has([data-invalid])::before {
  content: var(--tw-content);
  --tw-shadow-color: rgb(239 68 68 / 0.1);
  --tw-shadow: var(--tw-shadow-colored);
}

.data-\[disabled\]\:border-zinc-950\/20[data-disabled] {
  border-color: rgb(9 9 11 / 0.2);
}

.data-\[hover\]\:border-zinc-950\/20[data-hover] {
  border-color: rgb(9 9 11 / 0.2);
}

.data-\[invalid\]\:border-red-500[data-invalid] {
  --tw-border-opacity: 1;
  border-color: rgb(239 68 68 / var(--tw-border-opacity));
}

.data-\[invalid\]\:data-\[hover\]\:border-red-500[data-hover][data-invalid] {
  --tw-border-opacity: 1;
  border-color: rgb(239 68 68 / var(--tw-border-opacity));
}

.data-\[resize-handle-state\=drag\]\:border-gray-800[data-resize-handle-state=drag] {
  --tw-border-opacity: 1;
  border-color: rgb(31 41 55 / var(--tw-border-opacity));
}

.data-\[resize-handle-state\=hover\]\:border-gray-800[data-resize-handle-state=hover] {
  --tw-border-opacity: 1;
  border-color: rgb(31 41 55 / var(--tw-border-opacity));
}

.data-\[active\]\:bg-zinc-950\/5[data-active] {
  background-color: rgb(9 9 11 / 0.05);
}

.data-\[active\]\:bg-zinc-950\/\[2\.5\%\][data-active] {
  background-color: rgb(9 9 11 / 2.5%);
}

.data-\[checked\]\:bg-\[--switch-bg\][data-checked] {
  background-color: var(--switch-bg);
}

.data-\[disabled\]\:bg-zinc-200[data-disabled] {
  --tw-bg-opacity: 1;
  background-color: rgb(228 228 231 / var(--tw-bg-opacity));
}

.data-\[disabled\]\:data-\[checked\]\:bg-zinc-200[data-checked][data-disabled] {
  --tw-bg-opacity: 1;
  background-color: rgb(228 228 231 / var(--tw-bg-opacity));
}

.data-\[hover\]\:bg-zinc-950\/5[data-hover] {
  background-color: rgb(9 9 11 / 0.05);
}

.data-\[hover\]\:bg-zinc-950\/\[2\.5\%\][data-hover] {
  background-color: rgb(9 9 11 / 2.5%);
}

.data-\[selected\]\:bg-white[data-selected] {
  --tw-bg-opacity: 1;
  background-color: rgb(255 255 255 / var(--tw-bg-opacity));
}

.data-\[selected\]\:text-gray-800[data-selected] {
  --tw-text-opacity: 1;
  color: rgb(31 41 55 / var(--tw-text-opacity));
}

.data-\[disabled\]\:opacity-50[data-disabled] {
  opacity: 0.5;
}

.data-\[selected\]\:shadow-sm[data-selected] {
  --tw-shadow: 0 1px 2px 0 rgb(0 0 0 / 0.05);
  --tw-shadow-colored: 0 1px 2px 0 var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.data-\[focus\]\:outline[data-focus] {
  outline-style: solid;
}

.data-\[focus\]\:outline-2[data-focus] {
  outline-width: 2px;
}

.data-\[focus\]\:outline-offset-2[data-focus] {
  outline-offset: 2px;
}

.data-\[focus\]\:outline-blue-500[data-focus] {
  outline-color: #3b82f6;
}

.data-\[checked\]\:ring-\[--switch-bg-ring\][data-checked] {
  --tw-ring-color: var(--switch-bg-ring);
}

.data-\[disabled\]\:data-\[checked\]\:ring-black\/5[data-checked][data-disabled] {
  --tw-ring-color: rgb(0 0 0 / 0.05);
}

.data-\[hover\]\:data-\[checked\]\:ring-\[--switch-bg-ring\][data-checked][data-hover] {
  --tw-ring-color: var(--switch-bg-ring);
}

.data-\[hover\]\:ring-black\/15[data-hover] {
  --tw-ring-color: rgb(0 0 0 / 0.15);
}

.data-\[changing\]\:duration-200[data-changing] {
  transition-duration: 200ms;
}

.data-\[active\]\:\[--btn-border\:theme\(colors\.zinc\.950\/15\%\)\][data-active] {
  --btn-border: rgb(9 9 11 / 15%);
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.blue\.300\)\][data-active] {
  --btn-icon: #93c5fd;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.fuchsia\.200\)\][data-active] {
  --btn-icon: #f5d0fe;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.indigo\.200\)\][data-active] {
  --btn-icon: #c7d2fe;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.lime\.700\)\][data-active] {
  --btn-icon: #4d7c0f;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.orange\.200\)\][data-active] {
  --btn-icon: #fed7aa;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.pink\.200\)\][data-active] {
  --btn-icon: #fbcfe8;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.purple\.200\)\][data-active] {
  --btn-icon: #e9d5ff;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.red\.200\)\][data-active] {
  --btn-icon: #fecaca;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.rose\.200\)\][data-active] {
  --btn-icon: #fecdd3;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.violet\.200\)\][data-active] {
  --btn-icon: #ddd6fe;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.white\/80\%\)\][data-active] {
  --btn-icon: rgb(255 255 255 / 80%);
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.yellow\.700\)\][data-active] {
  --btn-icon: #a16207;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.zinc\.300\)\][data-active] {
  --btn-icon: #d4d4d8;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.zinc\.500\)\][data-active] {
  --btn-icon: #71717a;
}

.data-\[active\]\:\[--btn-icon\:theme\(colors\.zinc\.700\)\][data-active] {
  --btn-icon: #3f3f46;
}

.data-\[hover\]\:\[--btn-border\:theme\(colors\.zinc\.950\/15\%\)\][data-hover] {
  --btn-border: rgb(9 9 11 / 15%);
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.blue\.300\)\][data-hover] {
  --btn-icon: #93c5fd;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.fuchsia\.200\)\][data-hover] {
  --btn-icon: #f5d0fe;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.indigo\.200\)\][data-hover] {
  --btn-icon: #c7d2fe;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.lime\.700\)\][data-hover] {
  --btn-icon: #4d7c0f;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.orange\.200\)\][data-hover] {
  --btn-icon: #fed7aa;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.pink\.200\)\][data-hover] {
  --btn-icon: #fbcfe8;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.purple\.200\)\][data-hover] {
  --btn-icon: #e9d5ff;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.red\.200\)\][data-hover] {
  --btn-icon: #fecaca;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.rose\.200\)\][data-hover] {
  --btn-icon: #fecdd3;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.violet\.200\)\][data-hover] {
  --btn-icon: #ddd6fe;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.white\/80\%\)\][data-hover] {
  --btn-icon: rgb(255 255 255 / 80%);
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.yellow\.700\)\][data-hover] {
  --btn-icon: #a16207;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.zinc\.300\)\][data-hover] {
  --btn-icon: #d4d4d8;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.zinc\.500\)\][data-hover] {
  --btn-icon: #71717a;
}

.data-\[hover\]\:\[--btn-icon\:theme\(colors\.zinc\.700\)\][data-hover] {
  --btn-icon: #3f3f46;
}

.before\:data-\[disabled\]\:shadow-none[data-disabled]::before {
  content: var(--tw-content);
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.after\:data-\[active\]\:bg-\[--btn-hover-overlay\][data-active]::after {
  content: var(--tw-content);
  background-color: var(--btn-hover-overlay);
}

.after\:data-\[hover\]\:bg-\[--btn-hover-overlay\][data-hover]::after {
  content: var(--tw-content);
  background-color: var(--btn-hover-overlay);
}

.after\:data-\[disabled\]\:shadow-none[data-disabled]::after {
  content: var(--tw-content);
  --tw-shadow: 0 0 #0000;
  --tw-shadow-colored: 0 0 #0000;
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.group[data-checked] .group-data-\[checked\]\:translate-x-4 {
  --tw-translate-x: 1rem;
  transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
}

.group[data-checked] .group-data-\[checked\]\:bg-\[--switch\] {
  background-color: var(--switch);
}

.group[data-disabled][data-checked] .group-data-\[disabled\]\:group-data-\[checked\]\:bg-white {
  --tw-bg-opacity: 1;
  background-color: rgb(255 255 255 / var(--tw-bg-opacity));
}

.group[data-disabled][data-checked] .group-data-\[disabled\]\:group-data-\[checked\]\:shadow {
  --tw-shadow: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);
  --tw-shadow-colored: 0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);
  box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);
}

.group[data-checked] .group-data-\[checked\]\:shadow-\[--switch-shadow\] {
  --tw-shadow-color: var(--switch-shadow);
  --tw-shadow: var(--tw-shadow-colored);
}

.group[data-checked] .group-data-\[checked\]\:ring-\[--switch-ring\] {
  --tw-ring-color: var(--switch-ring);
}

.group[data-disabled][data-checked] .group-data-\[disabled\]\:group-data-\[checked\]\:ring-black\/5 {
  --tw-ring-color: rgb(0 0 0 / 0.05);
}

@media (min-width: 640px) {

  .sm\:size-3 {
    width: 0.75rem;
    height: 0.75rem;
  }

  .sm\:size-3\.5 {
    width: 0.875rem;
    height: 0.875rem;
  }

  .sm\:h-5 {
    height: 1.25rem;
  }

  .sm\:w-8 {
    width: 2rem;
  }

  .sm\:grid-cols-\[1fr_auto\] {
    grid-template-columns: 1fr auto;
  }

  .sm\:gap-x-6 {
    -moz-column-gap: 1.5rem;
         column-gap: 1.5rem;
  }

  .sm\:px-\[--gutter\] {
    padding-left: var(--gutter);
    padding-right: var(--gutter);
  }

  .sm\:px-\[calc\(theme\(spacing\.3\)-1px\)\] {
    padding-left: calc(0.75rem - 1px);
    padding-right: calc(0.75rem - 1px);
  }

  .sm\:px-\[calc\(theme\(spacing\[3\]\)-1px\)\] {
    padding-left: calc(0.75rem - 1px);
    padding-right: calc(0.75rem - 1px);
  }

  .sm\:py-\[calc\(theme\(spacing\[1\.5\]\)-1px\)\] {
    padding-top: calc(0.375rem - 1px);
    padding-bottom: calc(0.375rem - 1px);
  }

  .sm\:text-sm\/6 {
    font-size: 0.875rem;
    line-height: 1.5rem;
  }

  .sm\:text-xs {
    font-size: 0.75rem;
    line-height: 1rem;
  }

  .sm\:first\:pl-2:first-child {
    padding-left: 0.5rem;
  }

  .sm\:last\:pr-2:last-child {
    padding-right: 0.5rem;
  }

  .sm\:after\:focus-within\:ring-2:focus-within::after {
    content: var(--tw-content);
    --tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);
    --tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);
    box-shadow: var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);
  }

  .sm\:after\:focus-within\:ring-blue-500:focus-within::after {
    content: var(--tw-content);
    --tw-ring-opacity: 1;
    --tw-ring-color: rgb(59 130 246 / var(--tw-ring-opacity));
  }

  .group[data-checked] .sm\:group-data-\[checked\]\:translate-x-3 {
    --tw-translate-x: 0.75rem;
    transform: translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y));
  }
}

@media (min-width: 1024px) {

  .lg\:-ml-\[1px\] {
    margin-left: -1px;
  }

  .lg\:w-1\/2 {
    width: 50%;
  }

  .lg\:w-\[70dvw\] {
    width: 70dvw;
  }

  .lg\:flex-row {
    flex-direction: row;
  }

  .lg\:border-l {
    border-left-width: 1px;
  }

  .lg\:border-r {
    border-right-width: 1px;
  }
}

@media (min-width: 1280px) {

  .xl\:w-\[60dvw\] {
    width: 60dvw;
  }
}

@media (min-width: 1536px) {

  .\32xl\:w-\[50dvw\] {
    width: 50dvw;
  }
}

@media (forced-colors: active) {

  .forced-colors\:outline {
    outline-style: solid;
  }

  .forced-colors\:\[--btn-icon\:ButtonText\] {
    --btn-icon: ButtonText;
  }

  .forced-colors\:\[--switch-bg\:Highlight\] {
    --switch-bg: Highlight;
  }

  .forced-colors\:data-\[hover\]\:\[--btn-icon\:ButtonText\][data-hover] {
    --btn-icon: ButtonText;
  }
}

.\[\&\:\:-webkit-date-and-time-value\]\:min-h-\[1\.5em\]::-webkit-date-and-time-value {
  min-height: 1.5em;
}

.\[\&\:\:-webkit-datetime-edit-day-field\]\:p-0::-webkit-datetime-edit-day-field {
  padding: 0px;
}

.\[\&\:\:-webkit-datetime-edit-fields-wrapper\]\:p-0::-webkit-datetime-edit-fields-wrapper {
  padding: 0px;
}

.\[\&\:\:-webkit-datetime-edit-hour-field\]\:p-0::-webkit-datetime-edit-hour-field {
  padding: 0px;
}

.\[\&\:\:-webkit-datetime-edit-meridiem-field\]\:p-0::-webkit-datetime-edit-meridiem-field {
  padding: 0px;
}

.\[\&\:\:-webkit-datetime-edit-millisecond-field\]\:p-0::-webkit-datetime-edit-millisecond-field {
  padding: 0px;
}

.\[\&\:\:-webkit-datetime-edit-minute-field\]\:p-0::-webkit-datetime-edit-minute-field {
  padding: 0px;
}

.\[\&\:\:-webkit-datetime-edit-month-field\]\:p-0::-webkit-datetime-edit-month-field {
  padding: 0px;
}

.\[\&\:\:-webkit-datetime-edit-second-field\]\:p-0::-webkit-datetime-edit-second-field {
  padding: 0px;
}

.\[\&\:\:-webkit-datetime-edit-year-field\]\:p-0::-webkit-datetime-edit-year-field {
  padding: 0px;
}

.\[\&\:\:-webkit-datetime-edit\]\:inline-flex::-webkit-datetime-edit {
  display: inline-flex;
}

.\[\&\:\:-webkit-datetime-edit\]\:p-0::-webkit-datetime-edit {
  padding: 0px;
}

.\[\&\>\*\+\[data-slot\=control\]\]\:mt-6>*+[data-slot=control] {
  margin-top: 1.5rem;
}

.\[\&\>\[data-slot\=control\]\+\[data-slot\=description\]\]\:mt-3>[data-slot=control]+[data-slot=description] {
  margin-top: 0.75rem;
}

.\[\&\>\[data-slot\=control\]\+\[data-slot\=error\]\]\:mt-3>[data-slot=control]+[data-slot=error] {
  margin-top: 0.75rem;
}

.\[\&\>\[data-slot\=control\]\]\:col-start-2>[data-slot=control] {
  grid-column-start: 2;
}

.\[\&\>\[data-slot\=control\]\]\:self-center>[data-slot=control] {
  align-self: center;
}

.\[\&\>\[data-slot\=description\]\+\[data-slot\=control\]\]\:mt-3>[data-slot=description]+[data-slot=control] {
  margin-top: 0.75rem;
}

.\[\&\>\[data-slot\=description\]\]\:col-start-1>[data-slot=description] {
  grid-column-start: 1;
}

.\[\&\>\[data-slot\=description\]\]\:row-start-2>[data-slot=description] {
  grid-row-start: 2;
}

.\[\&\>\[data-slot\=icon\]\]\:-mx-0\.5>[data-slot=icon] {
  margin-left: -0.125rem;
  margin-right: -0.125rem;
}

.\[\&\>\[data-slot\=icon\]\]\:my-0\.5>[data-slot=icon] {
  margin-top: 0.125rem;
  margin-bottom: 0.125rem;
}

.\[\&\>\[data-slot\=icon\]\]\:size-5>[data-slot=icon] {
  width: 1.25rem;
  height: 1.25rem;
}

.\[\&\>\[data-slot\=icon\]\]\:shrink-0>[data-slot=icon] {
  flex-shrink: 0;
}

.\[\&\>\[data-slot\=icon\]\]\:text-\[--btn-icon\]>[data-slot=icon] {
  color: var(--btn-icon);
}

@media (min-width: 640px) {

  .\[\&\>\[data-slot\=icon\]\]\:sm\:my-1>[data-slot=icon] {
    margin-top: 0.25rem;
    margin-bottom: 0.25rem;
  }

  .\[\&\>\[data-slot\=icon\]\]\:sm\:size-4>[data-slot=icon] {
    width: 1rem;
    height: 1rem;
  }
}

.\[\&\>\[data-slot\=label\]\+\[data-slot\=control\]\]\:mt-3>[data-slot=label]+[data-slot=control] {
  margin-top: 0.75rem;
}

.\[\&\>\[data-slot\=label\]\+\[data-slot\=description\]\]\:mt-1>[data-slot=label]+[data-slot=description] {
  margin-top: 0.25rem;
}

.\[\&\>\[data-slot\=label\]\]\:col-start-1>[data-slot=label] {
  grid-column-start: 1;
}

.\[\&\>\[data-slot\=label\]\]\:row-start-1>[data-slot=label] {
  grid-row-start: 1;
}

.\[\&\>\[data-slot\=label\]\]\:justify-self-start>[data-slot=label] {
  justify-self: start;
}

.\[\&\>\[data-slot\=label\]\]\:font-medium>[data-slot=label] {
  font-weight: 500;
}

.\[\&\>\[data-slot\=text\]\]\:mt-1>[data-slot=text] {
  margin-top: 0.25rem;
}

.\[\&_\[data-slot\=label\]\]\:font-normal [data-slot=label] {
  font-weight: 400;
}

.\[\&_\[data-slot\=label\]\]\:has-\[\[data-slot\=description\]\]\:font-medium:has([data-slot=description]) [data-slot=label] {
  font-weight: 500;
}

@media(pointer:fine) {

  .\[\@media\(pointer\:fine\)\]\:hidden {
    display: none;
  }
}

:root {
  --vscode-textSeparator-foreground: rgba(0, 0, 0, 0.18);
}

/* @media (prefers-color-scheme: dark) {
  :root {
    --vscode-textSeparator-foreground: rgba(255, 255, 255, 0.18);
  }
} */

#viz {
  /* background-color: var(--vscode-editor-background); */
  color: var(--vscode-foreground);
  --vscode-font-family: -apple-system, BlinkMacSystemFont, sans-serif;
  --vscode-font-weight: normal;
  --vscode-font-size: 13px;
  --vscode-editor-font-family: Menlo, Monaco, "Courier New", monospace;
  --vscode-editor-font-weight: normal;
  --vscode-editor-font-size: 12px;
  --vscode-foreground: #616161;
  --vscode-disabledForeground: rgba(97, 97, 97, 0.5);
  --vscode-errorForeground: #a1260d;
  --vscode-descriptionForeground: #717171;
  --vscode-icon-foreground: #424242;
  --vscode-focusBorder: #0090f1;
  --vscode-textSeparator-foreground: rgba(0, 0, 0, 0.18);
  --vscode-textLink-foreground: #006ab1;
  --vscode-textLink-activeForeground: #006ab1;
  --vscode-textPreformat-foreground: #a31515;
  --vscode-textPreformat-background: rgba(0, 0, 0, 0.1);
  --vscode-textBlockQuote-background: #f2f2f2;
  --vscode-textBlockQuote-border: rgba(0, 122, 204, 0.5);
  --vscode-textCodeBlock-background: rgba(220, 220, 220, 0.4);
  --vscode-widget-shadow: rgba(0, 0, 0, 0.16);
  --vscode-widget-border: #d4d4d4;
  --vscode-input-background: #ffffff;
  --vscode-input-foreground: #616161;
  --vscode-inputOption-activeBorder: #007acc;
  --vscode-inputOption-hoverBackground: rgba(184, 184, 184, 0.31);
  --vscode-inputOption-activeBackground: rgba(0, 144, 241, 0.2);
  --vscode-inputOption-activeForeground: #000000;
  --vscode-input-placeholderForeground: #767676;
  --vscode-dropdown-background: #ffffff;
  --vscode-dropdown-foreground: #616161;
  --vscode-dropdown-border: #cecece;
  --vscode-button-foreground: #ffffff;
  --vscode-button-separator: rgba(255, 255, 255, 0.4);
  --vscode-button-background: #007acc;
  --vscode-button-hoverBackground: #0062a3;
  --vscode-button-secondaryForeground: #ffffff;
  --vscode-button-secondaryBackground: #5f6a79;
  --vscode-button-secondaryHoverBackground: #4c5561;
  --vscode-badge-background: #c4c4c4;
  --vscode-badge-foreground: #333333;
  --vscode-scrollbar-shadow: #dddddd;
  --vscode-scrollbarSlider-background: rgba(100, 100, 100, 0.4);
  --vscode-scrollbarSlider-hoverBackground: rgba(100, 100, 100, 0.7);
  --vscode-scrollbarSlider-activeBackground: rgba(0, 0, 0, 0.6);
  --vscode-progressBar-background: #0e70c0;
  --vscode-sash-hoverBorder: #0090f1;
  --vscode-editor-background: #ffffff;
  --vscode-editor-foreground: #000000;
  --vscode-quickInput-background: #f3f3f3;
  --vscode-quickInput-foreground: #616161;
  --vscode-quickInputTitle-background: rgba(0, 0, 0, 0.06);
  --vscode-pickerGroup-foreground: #0066bf;
  --vscode-pickerGroup-border: #cccedb;
  --vscode-keybindingLabel-background: rgba(221, 221, 221, 0.4);
  --vscode-keybindingLabel-foreground: #555555;
  --vscode-keybindingLabel-border: rgba(204, 204, 204, 0.4);
  --vscode-keybindingLabel-bottomBorder: rgba(187, 187, 187, 0.4);
  --vscode-searchEditor-findMatchBackground: rgba(234, 92, 0, 0.22);
  --vscode-search-resultsInfoForeground: #616161;
  --vscode-diffEditor-insertedTextBackground: rgba(156, 204, 44, 0.25);
  --vscode-diffEditor-removedTextBackground: rgba(255, 0, 0, 0.2);
  --vscode-diffEditor-insertedLineBackground: rgba(155, 185, 85, 0.2);
  --vscode-diffEditor-removedLineBackground: rgba(255, 0, 0, 0.2);
  --vscode-diffEditor-diagonalFill: rgba(34, 34, 34, 0.2);
  --vscode-diffEditor-unchangedRegionBackground: #e4e4e4;
  --vscode-diffEditor-unchangedRegionForeground: #4d4c4c;
  --vscode-diffEditor-unchangedCodeBackground: rgba(184, 184, 184, 0.16);
  --vscode-list-focusOutline: #0090f1;
  --vscode-list-hoverBackground: #e8e8e8;
  --vscode-tree-indentGuidesStroke: #a9a9a9;
  --vscode-tree-inactiveIndentGuidesStroke: rgba(169, 169, 169, 0.4);
  --vscode-tree-tableColumnsBorder: rgba(97, 97, 97, 0.13);
  --vscode-tree-tableOddRowsBackground: rgba(97, 97, 97, 0.04);
  --vscode-checkbox-background: #ffffff;
  --vscode-checkbox-selectBackground: #f3f3f3;
  --vscode-checkbox-foreground: #616161;
  --vscode-checkbox-border: #919191;
  --vscode-checkbox-selectBorder: #424242;
  --vscode-quickInputList-focusForeground: #ffffff;
  --vscode-quickInputList-focusIconForeground: #ffffff;
  --vscode-quickInputList-focusBackground: #0060c0;
  --vscode-toolbar-hoverBackground: rgba(184, 184, 184, 0.31);
  --vscode-toolbar-activeBackground: rgba(166, 166, 166, 0.31);
  --vscode-editor-snippetTabstopHighlightBackground: rgba(10, 50, 100, 0.2);
  --vscode-editor-snippetFinalTabstopHighlightBorder: rgba(10, 50, 100, 0.5);
  --vscode-problemsErrorIcon-foreground: #e51400;
  --vscode-problemsWarningIcon-foreground: #bf8803;
  --vscode-problemsInfoIcon-foreground: #1a85ff;
  --vscode-charts-foreground: #616161;
  --vscode-charts-lines: rgba(97, 97, 97, 0.5);
  --vscode-charts-red: #e51400;
  --vscode-charts-blue: #1a85ff;
  --vscode-charts-yellow: #bf8803;
  --vscode-charts-orange: #d18616;
  --vscode-charts-green: #388a34;
  --vscode-charts-purple: #652d90;
}

/* Dark theme not supported yet */

/* @media (prefers-color-scheme: dark) {
  #viz { */
/* background-color: var(--vscode-editor-background); */
/* color: var(--vscode-editor-foreground); */
/* VSCode default dark theme */
/* --vscode-font-family: -apple-system, BlinkMacSystemFont, sans-serif;
    --vscode-font-weight: normal;
    --vscode-font-size: 13px;
    --vscode-editor-font-family: Source Code Pro;
    --vscode-editor-font-weight: 400;
    --vscode-editor-font-size: 12px;
    --vscode-foreground: #cccccc;
    --vscode-errorForeground: #f48771;
    --vscode-descriptionForeground: rgba(204, 204, 204, 0.7);
    --vscode-icon-foreground: #c5c5c5;
    --vscode-focusBorder: #007fd4;
    --vscode-textSeparator-foreground: rgba(255, 255, 255, 0.18);
    --vscode-textLink-foreground: #3794ff;
    --vscode-textLink-activeForeground: #3794ff;
    --vscode-textPreformat-foreground: #d7ba7d;
    --vscode-textBlockQuote-background: rgba(127, 127, 127, 0.1);
    --vscode-textBlockQuote-border: rgba(0, 122, 204, 0.5);
    --vscode-textCodeBlock-background: rgba(10, 10, 10, 0.4);
    --vscode-widget-shadow: rgba(0, 0, 0, 0.36);
    --vscode-input-background: #3c3c3c;
    --vscode-input-foreground: #cccccc;
    --vscode-inputOption-activeBorder: rgba(0, 122, 204, 0);
    --vscode-inputOption-activeBackground: rgba(0, 127, 212, 0.4);
    --vscode-inputOption-activeForeground: #ffffff;
    --vscode-input-placeholderForeground: #a6a6a6;
    --vscode-dropdown-background: #3c3c3c;
    --vscode-dropdown-foreground: #f0f0f0;
    --vscode-dropdown-border: #3c3c3c;
    --vscode-checkbox-background: #3c3c3c;
    --vscode-checkbox-foreground: #f0f0f0;
    --vscode-checkbox-border: #3c3c3c;
    --vscode-button-foreground: #ffffff;
    --vscode-button-background: #0e639c;
    --vscode-button-hoverBackground: #1177bb;
    --vscode-button-secondaryForeground: #ffffff;
    --vscode-button-secondaryBackground: #3a3d41;
    --vscode-button-secondaryHoverBackground: #45494e;
    --vscode-badge-background: #4d4d4d;
    --vscode-badge-foreground: #ffffff;
    --vscode-scrollbar-shadow: #000000;
    --vscode-scrollbarSlider-background: rgba(121, 121, 121, 0.4);
    --vscode-scrollbarSlider-hoverBackground: rgba(100, 100, 100, 0.7);
    --vscode-scrollbarSlider-activeBackground: rgba(191, 191, 191, 0.4);
    --vscode-progressBar-background: #0e70c0;
    --vscode-sash-hoverBorder: #007fd4;
    --vscode-editor-background: #1e1e1e;
    --vscode-editor-foreground: #d4d4d4;
    --vscode-quickInput-background: #252526;
    --vscode-quickInput-foreground: #cccccc;
    --vscode-quickInputTitle-background: rgba(255, 255, 255, 0.1);
    --vscode-pickerGroup-foreground: #3794ff;
    --vscode-pickerGroup-border: #3f3f46;
    --vscode-keybindingLabel-background: rgba(128, 128, 128, 0.17);
    --vscode-keybindingLabel-foreground: #cccccc;
    --vscode-keybindingLabel-border: rgba(51, 51, 51, 0.6);
    --vscode-keybindingLabel-bottomBorder: rgba(68, 68, 68, 0.6);
    --vscode-searchEditor-findMatchBackground: rgba(234, 92, 0, 0.22);
    --vscode-diffEditor-insertedTextBackground: rgba(155, 185, 85, 0.2);
    --vscode-diffEditor-removedTextBackground: rgba(255, 0, 0, 0.2);
    --vscode-diffEditor-diagonalFill: rgba(204, 204, 204, 0.2);
    --vscode-list-focusOutline: #007fd4;
    --vscode-list-hoverBackground: #2a2d2e;
    --vscode-tree-indentGuidesStroke: #585858;
    --vscode-tree-tableColumnsBorder: rgba(204, 204, 204, 0.13);
    --vscode-quickInputList-focusForeground: #ffffff;
    --vscode-quickInputList-focusIconForeground: #ffffff;
    --vscode-quickInputList-focusBackground: #094771;
    --vscode-toolbar-hoverBackground: rgba(90, 93, 94, 0.31);
    --vscode-toolbar-activeBackground: rgba(99, 102, 103, 0.31);
    --vscode-problemsErrorIcon-foreground: #f14c4c;
    --vscode-problemsWarningIcon-foreground: #cca700;
    --vscode-problemsInfoIcon-foreground: #3794ff;
    --vscode-charts-foreground: #cccccc;
    --vscode-charts-lines: rgba(204, 204, 204, 0.5);
    --vscode-charts-red: #f14c4c;
    --vscode-charts-blue: #3794ff;
    --vscode-charts-yellow: #cca700;
    --vscode-charts-orange: #d18616;
    --vscode-charts-green: #89d185;
    --vscode-charts-purple: #b180d7;
  }
}*/

